<?php
// Exit if called directly
if (!defined('ABSPATH')) {
    exit();
}

if (!class_exists('S9_Core')) {

    /**
     * The main class and initialization point of the plugin.
     */
    class S9_Core
    {

        /**
         * Constructor
         */
        public function __construct()
        {
            $this->define_constants();
            // Declare constants and register files.
            add_action('s9_reset_admin_action', array($this, 'reset_settings_action'), 10, 2);
            add_action('admin_enqueue_scripts', array($this, 'register_admin_files'));
            add_action('admin_menu', array($this, 'create_oss_menu'));
            add_filter('plugin_action_links', array($this, 'oss_login_setting_links'), 10, 2);
            add_action('s9_reset_admin_ui', array($this, 'reset_settings'));
            add_action('s9_admin_header_ui', array($this, 's9_header_logo'));
        }

        /**
         * Add a settings link to the Plugins page,
         * so people can go straight from the plugin page to the settings page.
         */
        function oss_login_setting_links($links, $file)
        {
            static $thisPlugin = '';
            if (empty($thisPlugin)) {
                $thisPlugin = S9_ROOT_SETTING_LINK;
            }
            if ($file == $thisPlugin) {
                $settingsLink = '<a href="admin.php?page=social9">' . __('Settings', 'Social9') . '</a>';

                array_unshift($links, $settingsLink);
            }
            return $links;
        }

        /**
         * Create menu.
         */
        function create_oss_menu()
        {
            // Create Menu.
            add_menu_page('Social9', 'Social9', 'manage_options', 'social9', array('S9_Activation_Admin', 'options_page'), S9_CORE_URL . 'assets/images/favicon.ico');
            add_submenu_page('social9', 'Activation Settings', 'Activation', 'manage_options', 'social9', array('S9_Activation_Admin', 'options_page'));
            // Customize Menu based on do_action order
            do_action('s9_admin_page');
        }

        /**
         * Define constants needed across the plug-in.
         */
        public function define_constants()
        {
            define('S9_CORE_DIR', plugin_dir_path(__FILE__));
            define('S9_CORE_URL', plugin_dir_url(__FILE__));
            require_once(S9_CORE_DIR . 'admin/s9-activate-admin.php');
        }

        /**
         * Registers Scripts and Styles needed throughout front end of plugin
         *
         */
        public function register_admin_files()
        {
            wp_register_style('s9-admin-style', S9_CORE_URL . 'assets/css/s9-admin-style.css', array(), S9_PLUGIN_VERSION);
            wp_enqueue_style('s9-admin-style');
        }

        public function s9_header_logo()
        {
?>
            <header class="s9_header">
                <a href="#">
                    <svg version="1.1" id="Layer_1" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" x="0px" y="0px" viewBox="0 0 119 29" style="enable-background: new 0 0 119 29" xml:space="preserve">
                        <style type="text/css">
                            .st0 {
                                fill: #4285f4;
                            }

                            .st1 {
                                fill: #fbbc05;
                            }

                            .st2 {
                                fill: #ea4335;
                            }

                            .st3 {
                                fill: #34a853;
                            }

                            .st4 {
                                fill: #202942;
                            }

                            .st5 {
                                display: none;
                                fill: #f9917a;
                            }
                        </style>
                        <g id="Layer_2_1_">
                            <g id="icon">
                                <path class="st0" d="M14.7,24.2c-4.9-0.5-8.7-4.7-8.6-9.6c0-1,0.1-1.9,0.4-2.8L3.8,11c-2,6.6,1.7,13.6,8.4,15.6
			c1.1,0.3,2.2,0.5,3.4,0.5L14.7,24.2z M26.9,8.7l-2.2,2c2.1,4.9-0.3,10.6-5.2,12.7c-0.6,0.2-1.2,0.4-1.8,0.6l0.7,2.7
			c6.8-1.5,11.1-8.1,9.6-14.9C27.7,10.7,27.3,9.7,26.9,8.7L26.9,8.7z" />
                                <path class="st0" d="M25.2,6.4l-2.1,1.9c-1.7-2-4-3.2-6.6-3.4c-0.3,0-0.5,0-0.8,0c-3.2,0-6.2,1.6-8,4.3l-2.8-1
			c3.5-6,11.1-8,17.1-4.5l0,0C23.3,4.4,24.3,5.3,25.2,6.4L25.2,6.4z" />
                                <circle class="st1" cx="21.4" cy="4.8" r="4.8" />
                                <circle class="st2" cx="4.8" cy="14.5" r="4.8" />
                                <circle class="st3" cx="21.4" cy="24.2" r="4.8" />
                            </g>
                            <g id="social9">
                                <g>
                                    <path class="st4" d="M52,18.8c0,1.6-0.6,3-1.8,4s-2.7,1.5-4.4,1.5c-1.6,0-2.9-0.5-4.1-1.4c-1.2-0.9-2-2.1-2.5-3.7l2.3-0.9
				c0.2,0.6,0.4,1.1,0.7,1.5c0.3,0.5,0.6,0.8,1,1.2c0.4,0.3,0.8,0.6,1.2,0.8c0.5,0.2,0.9,0.3,1.4,0.3c1.1,0,2-0.3,2.7-0.9
				s1-1.3,1-2.3c0-0.8-0.3-1.5-0.9-2c-0.5-0.5-1.6-1.1-3-1.6c-1.5-0.5-2.4-0.9-2.8-1.1c-2-1-3-2.5-3-4.5c0-1.4,0.5-2.6,1.6-3.5
				c1.1-1,2.5-1.5,4.1-1.5c1.4,0,2.7,0.4,3.7,1.1s1.7,1.6,2.1,2.7L49,9.4c0-0.7-0.4-1.3-1-1.7C47.4,7.2,46.6,7,45.7,7
				c-0.9,0-1.7,0.3-2.4,0.8c-0.6,0.5-1,1.1-1,1.9c0,0.6,0.3,1.2,0.8,1.7c0.6,0.5,1.8,1,3.6,1.7c1.9,0.6,3.3,1.4,4.1,2.4
				C51.6,16.3,52,17.5,52,18.8z" />
                                    <path class="st4" d="M53.8,17.4c0-2,0.6-3.6,1.9-4.9c1.3-1.3,2.8-1.9,4.7-1.9s3.5,0.6,4.7,1.9c1.3,1.3,1.9,2.9,1.9,4.9
				s-0.6,3.6-1.9,4.9c-1.2,1.3-2.8,1.9-4.7,1.9s-3.5-0.6-4.7-1.9C54.4,21,53.8,19.4,53.8,17.4z M56.2,17.4c0,1.4,0.4,2.5,1.2,3.4
				s1.8,1.3,3,1.3s2.2-0.4,3-1.3c0.8-0.9,1.2-2,1.2-3.4s-0.4-2.5-1.2-3.3c-0.8-0.9-1.8-1.3-3-1.3s-2.2,0.4-3,1.3
				C56.6,14.9,56.2,16,56.2,17.4z" />
                                    <path class="st4" d="M75,24.2c-1.9,0-3.5-0.6-4.7-1.9s-1.9-3-1.9-4.9c0-2,0.6-3.6,1.9-4.9s2.8-1.9,4.7-1.9c1.3,0,2.5,0.3,3.4,1
				c1,0.7,1.7,1.6,2.2,2.7l-2.2,0.9c-0.7-1.6-1.9-2.4-3.6-2.4c-1.1,0-2.1,0.4-2.9,1.3c-0.8,0.9-1.2,2-1.2,3.3s0.4,2.4,1.2,3.3
				c0.8,0.9,1.8,1.3,2.9,1.3c1.8,0,3-0.8,3.7-2.4l2.1,0.9c-0.5,1.2-1.2,2.1-2.2,2.7S76.4,24.2,75,24.2z" />
                                </g>
                                <g>
                                    <path class="st4" d="M86,6.6c0,0.5-0.2,0.9-0.5,1.2c-0.3,0.3-0.7,0.5-1.2,0.5S83.4,8.1,83,7.8c-0.4-0.3-0.5-0.7-0.5-1.2
				s0.2-0.9,0.5-1.2c0.4-0.4,0.8-0.5,1.3-0.5s0.9,0.2,1.2,0.5C85.8,5.7,86,6.1,86,6.6z M85.5,11v12.8H83V11H85.5z" />
                                </g>
                                <g>
                                    <path class="st4" d="M93.3,10.6c1.8,0,3.2,0.5,4.2,1.4s1.5,2.3,1.5,3.9v7.9h-2.3V22h-0.1c-1,1.5-2.3,2.2-4,2.2
				c-1.4,0-2.6-0.4-3.5-1.3c-1-0.8-1.4-1.9-1.4-3.1c0-1.3,0.5-2.4,1.5-3.2c1-0.8,2.3-1.2,4-1.2c1.4,0,2.6,0.3,3.5,0.8v-0.5
				c0-0.8-0.3-1.5-1-2.1s-1.4-0.9-2.3-0.9c-1.3,0-2.4,0.6-3.2,1.7l-2.1-1.3C89.3,11.4,91.1,10.6,93.3,10.6z M90.2,19.9
				c0,0.6,0.3,1.2,0.8,1.6s1.2,0.6,1.9,0.6c1,0,1.9-0.4,2.7-1.1s1.2-1.6,1.2-2.6c-0.8-0.6-1.8-0.9-3.1-0.9c-1,0-1.8,0.2-2.4,0.7
				C90.5,18.6,90.2,19.2,90.2,19.9z" />
                                    <path class="st4" d="M104.2,5.1v18.7h-2.4V5.1H104.2z" />
                                    <path class="st4" d="M112.3,17.3c-1.4,0-2.7-0.6-3.9-1.7c-1.1-1.2-1.7-2.5-1.7-4.1c0-1.6,0.6-3,1.8-4.2c1.2-1.2,2.7-1.8,4.3-1.8
				c1.7,0,3.2,0.6,4.4,1.8c1.2,1.2,1.8,2.6,1.8,4.2c0,1.4-0.6,3.1-1.8,4.9l-5.2,7.8l-1.9-1.3l4.4-6.1l-0.1-0.1
				C113.9,17.1,113.2,17.3,112.3,17.3z M116.6,11.5c0-1-0.4-1.9-1.1-2.6c-0.7-0.7-1.6-1.1-2.6-1.1s-1.9,0.4-2.7,1.1
				c-0.7,0.7-1.1,1.6-1.1,2.6s0.4,1.9,1.1,2.6c0.8,0.7,1.6,1.1,2.6,1.1s1.9-0.4,2.6-1.1C116.2,13.4,116.6,12.5,116.6,11.5z" />
                                </g>
                            </g>
                        </g>
                        <path class="st5" d="M128.7,0.4h24.5c1.9,0,3.5,1.6,3.5,3.5v6.5c0,1.9-1.6,3.5-3.5,3.5h-24.5c-1.9,0-3.5-1.6-3.5-3.5V3.9
	           C125.2,2,126.7,0.4,128.7,0.4z" />
                    </svg>
                </a>
            </header>
            <div class="s9-loading"></div>
            <?php
        }
        /**
         * 
         * @param type $option_name
         */
        public function reset_settings($option_name)
        {
            if (current_user_can('manage_options')) {
            ?>
                <div class="s9_section-header">
                    <h1><?php _e('Your Social9 Account is Activated.', 'Social9'); ?></h1>
                    <p><?php _e('Reset all the ' . $option_name . ' options to the default recommended settings.', 'Social9'); ?></p>
                </div>
                <div>
                    <form method="post" action="" class="s9-reset">
                        <?php submit_button('Reset All Options', 'primary', 'reset', false); ?>
                    </form>
                </div>

<?php
            }
        }

        /**
         * 
         * @param type $option
         * @param type $settings
         */
        public static function reset_settings_action($option, $settings)
        {
            if (current_user_can('manage_options')) {
                update_option($option, $settings);
            }
        }

        /**
         * Reset Sharing Settings.
         */
        public static function reset_share_options()
        {
            update_option('social9_account_id', '');
            update_option('social9_apikey', '');
            update_option('social9_access_token', '');
        }
    }

    new S9_Core();
}
